###############################################################################
# File Name         : ptp-ha_logs.tcl                                         #
# File Version      : 1.8                                                     #
# Component Name    : Logs                                                    #
# Module Name       : Precision Time Protocol - High Accuracy                 #
###############################################################################
# History       Date       Author         Addition/ Alteration                #
###############################################################################
#                                                                             #
#  1.0       Mar/2018      CERN           Initial                             #
#  1.1       Jun/2018      CERN           Added missing variables             #
#                                         L1SYNC_NRX_P2_O, L1SYNC_NRX_P2_V,   #
#                                         L1SYNC_RX_P2_F, L1SYNC_NRX_P2_F,    #
#                                         DELAY_RESP_RX_F, CONVERT_DUT_EPOCH, #
#                                         CHECK_STATE_CONFIG_MATCH_F          #
#  1.2       Jun/2018      CERN           Improved log messages               #
#  1.3       Sep/2018      CERN           Added more logs                     #
#  1.4       Sep/2018      CERN           Added more logs                     #
#  1.5       Nov/2018      CERN           Added new variable to resolve script#
#                                         error in PCG_006.                   #
#  1.6       Nov/2018      CERN           a) Replaced SEIT with SEET.         #
#                                         b) Added more logs.                 #
#  1.7       Dec/2018      CERN           Added variables for                 #
#                                         L1SyncReceiptTimeout.               #
#  1.8       Feb/2019      CERN           Added more logs.                    #
#                                                                             #
###############################################################################
# Copyright (c) 2018 - 2019 CERN                                              #
###############################################################################


### DUT LOG MESSAGES ###

set dut_log_msg(ACP.DISABLE)                    "Disable asymmetryCorrectionPortDS.enable.\n"
set dut_log_msg(ACP.DISABLE_F)                  "AsymmetryCorrectionPortDS.enable cannot be disabled.\n"
set dut_log_msg(ACP.ENABLE)                     "Enable asymmetryCorrectionPortDS.enable.\n"
set dut_log_msg(ACP.ENABLE_F)                   "Unable to enable asymmetryCorrectionPortDS.enable on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ACP.ENABLE_V)                   "Verify whether asymmetryCorrectionPortDS.enable is set to TRUE on port P1 ($::dut_port_num_1).\n" 
set dut_log_msg(ACP.ENABLE_VF)                  "AsymmetryCorrectionPortDS.enable is not set to TRUE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ANNOUNCE_RX_P1_F)               "DUT has not transmitted ANNOUNCE message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ANNOUNCE_RX_P1_O)               "Observe that DUT transmits ANNOUNCE message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CALCULATE_TIME_DIFF_TD1)        "Calculate time difference TD1.\n"
set dut_log_msg(CALCULATE_TIME_DIFF_TD2)        "Calculate time difference TD2.\n"
set dut_log_msg(CALCULATE_TIME_DIFF_TD3)        "Calculate time difference TD3.\n"
set dut_log_msg(CF1_F)                          "CF1 is not equal to 0.\n"
set dut_log_msg(CF5_F)                          "CF5 is not equal to 0.\n"
set dut_log_msg(CF1_V)                          "Check whether CF1 = 0.\n"
set dut_log_msg(CF2_DA2_F)                      "CF2 is not equal to (-1) * DA2.\n"
set dut_log_msg(CF2_DA2_V)                      "Check whether CF2 = (-1) * DA2.\n"
set dut_log_msg(CF3_DA3_F)                      "CF3 is not equal to (-1) * DA3.\n"
set dut_log_msg(CF3_DA3_V)                      "Check whether CF3 = (-1) * DA3.\n"
set dut_log_msg(CF4_DA4_F)                      "CF4 is not equal to (-1) * DA4.\n"
set dut_log_msg(CF4_DA4_V)                      "Check whether CF4 = (-1) * DA4.\n"
set dut_log_msg(CF5_DA5_F)                      "CF5 is not equal to (-1) * DA5.\n"
set dut_log_msg(CF5_DA5_V)                      "Check whether CF5 = (-1) * DA5.\n"
set dut_log_msg(CF5_0_V)                        "Verify whether CF5 = 0.\n"
set dut_log_msg(CHECK_EXPR)                     "Verify whether ((Tb - Ta) + (Tc - Tb))/2 is satisfied.\n"
set dut_log_msg(CHECK_EXPR_DA2)                 "Check whether DA2 = (1/3) * MD2.\n"
set dut_log_msg(CHECK_EXPR_DA2_F)               "Value of delayAsymmetry is not as expected in DUT.\n"
set dut_log_msg(CHECK_EXPR_DA3)                 "Check whether DA3 = (1/3) * MD2 + 2^(32+16).\n"
set dut_log_msg(CHECK_EXPR_DA3_F)               "Value of delayAsymmetry is not as expected in DUT.\n"
set dut_log_msg(CHECK_EXPR_DA4)                 "Check whether DA4 = (-1) * MD4.\n"
set dut_log_msg(CHECK_EXPR_DA4_F)               "Value of delayAsymmetry is not as expected in DUT.\n"
set dut_log_msg(CHECK_EXPR_DA5)                 "Check whether DA5 = (-1) * MD5.\n"
set dut_log_msg(CHECK_EXPR_DA5_F)               "Value of delayAsymmetry is not as expected in DUT.\n"
set dut_log_msg(CHECK_EXPR_DA5_MLD)             "Check whether DA5 = (-1) * MLD5.\n"
set dut_log_msg(CHECK_EXPR_DA5_MLD_F)           "Value of delayAsymmetry is not as expected in DUT.\n"
set dut_log_msg(CHECK_EXPR_F)                   "((Tb - Ta) + (Tc - Tb))/2 is not satisfied to the expected value.\n"
set dut_log_msg(CHECK_EXPRESSION_DA2)           "Check whether DA2 = (1/3) * MLD2.\n"
set dut_log_msg(CHECK_EXPRESSION_DA3)           "Check whether DA3 = (1/3) * MLD2 + 2^(32+16).\n"
set dut_log_msg(CHECK_EXPRESSION_DA4)           "Check whether DA4 = (-1) * MLD4.\n"
set dut_log_msg(CHECK_EXPRESSION_F)             "Check for the expression has failed.\n"
set dut_log_msg(CHECK_MD2_MD1)                  "Check whether MD2 = MD1.\n"
set dut_log_msg(CHECK_MD2_MD1_F)                "MD2 is not equal to MD1.\n"
set dut_log_msg(CHECK_MD3_MD1)                  "Check whether MD3 = MD1.\n"
set dut_log_msg(CHECK_MD3_MD1_F)                "MD3 is not equal to MD1.\n"
set dut_log_msg(CHECK_MD4_MD1)                  "Check whether MD4 = MD1.\n"
set dut_log_msg(CHECK_MD4_MD1_F)                "MD4 is not equal to MD1.\n"
set dut_log_msg(CHECK_MD5_MD1)                  "Check whether MD5 = MD1.\n"
set dut_log_msg(CHECK_MD5_MD1_F)                "MD5 is not equal to MD1.\n"
set dut_log_msg(CHECK_MLD2_MLD1)                "Check whether MLD2 = MLD1.\n"
set dut_log_msg(CHECK_MLD2_MLD1_F)              "MLD2 is not equal to MLD1.\n"
set dut_log_msg(CHECK_MLD3_MLD1)                "Check whether MLD3 = MLD1.\n"
set dut_log_msg(CHECK_MLD3_MLD1_F)              "MLD3 is not equal to MLD1.\n"
set dut_log_msg(CHECK_MLD4_MLD1)                "Check whether MLD4 = MLD1.\n"
set dut_log_msg(CHECK_MLD4_MLD1_F)              "MLD4 is not equal to MLD1.\n"
set dut_log_msg(CHECK_MLD5_MLD1)                "Check whether MLD5 = MLD1.\n"
set dut_log_msg(CHECK_MLD5_MLD1_F)              "MLD5 is not equal to MLD1.\n"
set dut_log_msg(CHECK_LOWEST_OFM_V)             "Check non-zero absolute value of currentDS.offsetFromMaster in DUT becomes lowest possible value ($::offset_from_master ns).\n"
set dut_log_msg(CHECK_LOWEST_OFM_F)             "Unable to check the absolute value of currentDS.offsetFromMaster in DUT.\n"
set dut_log_msg(CHECK_STATE_CONFIG_MATCH_F)     "L1SYNC port status of P1 ($::dut_port_num_1) is not CONFIG_MATCH.\n"
set dut_log_msg(CHECK_STATE_CONFIG_MATCH_P1_F)  "L1SYNC port status of P1 ($::dut_port_num_1) is not CONFIG_MATCH.\n"
set dut_log_msg(CHECK_STATE_CONFIG_MATCH_P1_O)  "Observe that L1SYNC port status of P1 ($::dut_port_num_1) is CONFIG_MATCH.\n"
set dut_log_msg(CHECK_STATE_CONFIG_MATCH_P1_V)  "Verify that L1SYNC port status of P1 ($::dut_port_num_1) is CONFIG_MATCH.\n"
set dut_log_msg(CHECK_STATE_DISABLED_P1_F)      "L1SYNC port status of P1 ($::dut_port_num_1) is not DISABLED.\n"
set dut_log_msg(CHECK_STATE_DISABLED_P1_O)      "Observe that L1SYNC port status of P1 ($::dut_port_num_1) is DISABLED.\n"
set dut_log_msg(CHECK_STATE_DISABLED_P1_V)      "Verify that L1SYNC port status of P1 ($::dut_port_num_1) is DISABLED.\n"
set dut_log_msg(CHECK_STATE_FAULTY_P1_F)        "PTP port status of port P1 ($::dut_port_num_1) is not FAULTY.\n"
set dut_log_msg(CHECK_STATE_FAULTY_P1_V)        "Verify that the PTP port status of P1 ($::dut_port_num_1) is FAULTY.\n"
set dut_log_msg(CHECK_STATE_IDLE_P1_F)          "L1SYNC port status of P1 ($::dut_port_num_1) is not IDLE.\n"
set dut_log_msg(CHECK_STATE_IDLE_P1_O)          "Observe that L1SYNC port status of P1 ($::dut_port_num_1) is IDLE.\n"
set dut_log_msg(CHECK_STATE_IDLE_P1_V)          "Verify that L1SYNC port status of P1 ($::dut_port_num_1) is IDLE.\n"
set dut_log_msg(CHECK_STATE_L1_SYNC_UP_P1_F)    "L1SYNC port status of P1 ($::dut_port_num_1) is not L1_SYNC_UP.\n"
set dut_log_msg(CHECK_STATE_L1_SYNC_UP_P1_O)    "Observe that L1SYNC port status of P1 ($::dut_port_num_1) is L1_SYNC_UP.\n"
set dut_log_msg(CHECK_STATE_L1_SYNC_UP_P1_V)    "Verify that L1SYNC port status of P1 ($::dut_port_num_1) is L1_SYNC_UP.\n"
set dut_log_msg(CHECK_STATE_LINK_ALIVE_F)       "L1SYNC port status of P1 ($::dut_port_num_1) is not LINK_ALIVE.\n"
set dut_log_msg(CHECK_STATE_LINK_ALIVE_P1_F)    "L1SYNC port status of P1 ($::dut_port_num_1) is not LINK_ALIVE.\n"
set dut_log_msg(CHECK_STATE_LINK_ALIVE_P1_O)    "Observe that L1SYNC port status of P1 ($::dut_port_num_1) is LINK_ALIVE.\n"
set dut_log_msg(CHECK_STATE_LINK_ALIVE_P1_V)    "Verify that L1SYNC port status of P1 ($::dut_port_num_1) is LINK_ALIVE.\n"
set dut_log_msg(CHECK_STATE_LISTENING_P1_F)     "PTP port status of P1 ($::dut_port_num_1) is not LISTENING.\n"
set dut_log_msg(CHECK_STATE_LISTENING_P1_O)     "Observe that the PTP port status of P1 ($::dut_port_num_1) is LISTENING.\n"
set dut_log_msg(CHECK_STATE_LISTENING_P1_V)     "Verify that the PTP port status of P1 ($::dut_port_num_1) is LISTENING.\n"
set dut_log_msg(CHECK_STATE_MASTER_P1_F)        "PTP port status of P1 ($::dut_port_num_1) is not MASTER.\n"
set dut_log_msg(CHECK_STATE_MASTER_P1_O)        "Observe that PTP port status of P1 ($::dut_port_num_1) is MASTER.\n"
set dut_log_msg(CHECK_STATE_MASTER_P1_V)        "Verify that PTP port status of P1 ($::dut_port_num_1) is MASTER.\n"
set dut_log_msg(CHECK_STATE_MASTER_P2_F)        "PTP port status of P2 ($::dut_port_num_2) is not MASTER.\n"
set dut_log_msg(CHECK_STATE_MASTER_P2_O)        "Observe that PTP port status of P2 ($::dut_port_num_2) is MASTER.\n"
set dut_log_msg(CHECK_STATE_MASTER_P2_V)        "Verify that PTP port status of P2 ($::dut_port_num_2) is MASTER.\n"
set dut_log_msg(CHECK_STATE_PASSIVE_P1_F)       "PTP port status of P1 ($::dut_port_num_1) is not PASSIVE.\n"
set dut_log_msg(CHECK_STATE_PASSIVE_P1_O)       "Observe that PTP port status of P1 ($::dut_port_num_1) is PASSIVE.\n"
set dut_log_msg(CHECK_STATE_PASSIVE_P1_V)       "Verify that PTP port status of P1 ($::dut_port_num_1) is PASSIVE.\n"
set dut_log_msg(CHECK_STATE_PRE_MASTER_P1_F)    "PTP port status of P1 ($::dut_port_num_1) is not PRE_MASTER.\n" 
set dut_log_msg(CHECK_STATE_PRE_MASTER_P1_O)    "Observe that PTP port status of P1 ($::dut_port_num_1) is PRE_MASTER.\n"
set dut_log_msg(CHECK_STATE_PRE_MASTER_P1_V)    "Verify that PTP port status of P1 ($::dut_port_num_1) is PRE_MASTER.\n"
set dut_log_msg(CHECK_STATE_SLAVE_P1_F)         "PTP port status of P1 ($::dut_port_num_1) is not SLAVE.\n"
set dut_log_msg(CHECK_STATE_SLAVE_P1_O)         "Observe that PTP port status of P1 ($::dut_port_num_1) is SLAVE.\n"
set dut_log_msg(CHECK_STATE_SLAVE_P1_V)         "Verify that PTP port status of P1 ($::dut_port_num_1) is SLAVE.\n"
set dut_log_msg(CHECK_STATE_UNCALIBRATED_P1_F)  "PTP port status of P1 ($::dut_port_num_1) is not UNCALIBRATED.\n"
set dut_log_msg(CHECK_STATE_UNCALIBRATED_P1_O)  "Observe that PTP port status of P1 ($::dut_port_num_1) is UNCALIBRATED.\n"
set dut_log_msg(CHECK_STATE_UNCALIBRATED_P1_V)  "Verify that PTP port status of P1 ($::dut_port_num_1) is UNCALIBRATED.\n"
set dut_log_msg(CHECK_STATE_UNCALIBRATED_P2_F)  "PTP port status of P2 ($::dut_port_num_1) is not UNCALIBRATED.\n"
set dut_log_msg(CHECK_STATE_UNCALIBRATED_P2_O)  "Observe that PTP port status of P2 ($::dut_port_num_1) is UNCALIBRATED.\n"
set dut_log_msg(CHECK_STATE_UNCALIBRATED_P2_V)  "Verify that PTP port status of P2 ($::dut_port_num_1) is UNCALIBRATED.\n"
set dut_log_msg(CONFIG_ANN_INTVL)               "Configure Log Announce Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ANN_INTVL_0)             "Configure Log Announce Interval as 0 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ANN_INTVL_1)             "Configure Log Announce Interval as 1 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ANN_INTVL_4)             "Configure Log Announce Interval as 4 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ANN_INTVL_F)             "Unable to configure Log Announce Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ANN_TIMEOUT)             "Configure Announce timeout on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ANN_TIMEOUT_10)          "Configure announceReceiptTimeout as 10 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ANN_TIMEOUT_2)           "Configure announceReceiptTimeout as 2 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ANN_TIMEOUT_3)           "Configure announceReceiptTimeout as 3 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ANN_TIMEOUT_F)           "Unable to configure Announce timeout on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_ASC.CONSTANTASYMMETRY)   "Configure asymmetryCorrectionDS.constantAsymmetry.\n"
set dut_log_msg(CONFIG_ASC.CONSTANTASYMMETRY_F) "Unable to configure asymmetryCorrectionDS.constantAsymmetry.\n"
set dut_log_msg(CONFIG_ASC.DELAYCOEFFICIENT)    "Configure asymmetryCorrectionPortDS.scaledDelayCoefficient.\n"
set dut_log_msg(CONFIG_ASC.DELAYCOEFFICIENT_F)  "Unable to configure asymmetryCorrectionPortDS.scaledDelayCoefficient.\n"
set dut_log_msg(CONFIG_DELAYREQ_INTVL)          "Configure DelayRequest Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_DELAYREQ_INTVL_0)        "Configure DelayRequest Interval as 0 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_DELAYREQ_INTVL_1)        "Configure DelayRequest Interval as 1 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_DELAYREQ_INTVL_5)        "Configure DelayRequest Interval as 5 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_DELAYREQ_INTVL_F)        "Unable to configure DelayRequest Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_L1SYNC_INTVL)            "Configure L1Sync Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_L1SYNC_INTVL_0)          "Configure L1Sync Interval as 0 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_L1SYNC_INTVL_4)          "Configure L1Sync Interval as 4 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_L1SYNC_INTVL_4_P1)       "Configure L1Sync Interval as -4 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_L1SYNC_INTVL_F)          "Unable to configure L1Sync Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_L1SYNC_TIMEOUT)          "Configure L1SyncReceiptTimeout on DUT.\n"
set dut_log_msg(CONFIG_L1SYNC_TIMEOUT_10)       "Configure L1SyncReceiptTimeout as 10 on DUT.\n"
set dut_log_msg(CONFIG_L1SYNC_TIMEOUT_2)        "Configure L1SyncReceiptTimeout as 2 on DUT.\n"
set dut_log_msg(CONFIG_L1SYNC_TIMEOUT_3)        "Configure L1SyncReceiptTimeout as 3 on DUT.\n"
set dut_log_msg(CONFIG_L1SYNC_TIMEOUT_F)        "Unable to configure L1SyncReceiptTimeout on DUT.\n"
set dut_log_msg(CONFIG_MO)                      "Enable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_MO_F)                    "Unable to enable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_MO_P1)                   "Enable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_MO_P1_F)                 "Unable to enable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_PDELAYREQ_INTVL)         "Configure PDelayRequest Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_PDELAYREQ_INTVL_0)       "Configure PDelayRequest Interval as 0 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_PDELAYREQ_INTVL_2)       "Configure PDelayRequest Interval as 2 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_PDELAYREQ_INTVL_5)       "Configure PDelayRequest Interval as 5 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_PDELAYREQ_INTVL_F)       "Unable to configure PDelayRequest Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_SYNC_INTVL)              "Configure Sync Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_SYNC_INTVL_0)            "Configure Sync Interval as 0 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_SYNC_INTVL_1)            "Configure Sync Interval as -1 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_SYNC_INTVL_1_P1)         "Configure Sync Interval as 1 on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_SYNC_INTVL_F)            "Unable to configure Sync Interval on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_TXPORTDS.EGRESSLATENCY)  "Configure timestampCorrectionPortDS.egressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_TXPORTDS.EGRESSLATENCY_F)    "Unable to configure timestampCorrectionPortDS.egressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_TXPORTDS.INGRESSLATENCY)     "Configure timestampCorrectionPortDS.ingressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIG_TXPORTDS.INGRESSLATENCY_F)   "Unable to configure timestampCorrectionPortDS.ingressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_DN)                   "Configure domain number at DUT.\n"
set dut_log_msg(CONFIGURE_DN_0)                 "Configure domain number as 0 at DUT.\n"
set dut_log_msg(CONFIGURE_DN_1)                 "Observe that DUT does not allow to configure domain number at DUT.\n"
set dut_log_msg(CONFIGURE_DN_127)               "Configure domain number as 127 at DUT.\n"
set dut_log_msg(CONFIGURE_DN_F)                 "Unable to configure domain number at DUT.\n"
set dut_log_msg(CONFIGURE_DN_N_F)               "DUT allows to configure Domain number at DUT.\n"
set dut_log_msg(CONFIGURE_FAULTY)               "Configure externalPortConfigurationPortDS.desiredState as FAULTY on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_FAULTY_F)             "Unable to configure externalPortConfigurationPortDS.desiredState as FAULTY on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_LISTENING)            "Configure externalPortConfigurationPortDS.desiredState as LISTENING on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_LISTENING_F)          "Unable to configure externalPortConfigurationPortDS.desiredState as LISTENING on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_MASTER)               "Configure externalPortConfigurationPortDS.desiredState as MASTER on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_MASTER_F)             "Unable to configure externalPortConfigurationPortDS.desiredState as MASTER on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_MASTER_ONLY)          "Enable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_MASTER_ONLY_F)        "Unable to enable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_PASSIVE)              "Configure externalPortConfigurationPortDS.desiredState as PASSIVE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_PASSIVE_F)            "Unable to configure externalPortConfigurationPortDS.desiredState as PASSIVE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_PRE_MASTER)           "Configure externalPortConfigurationPortDS.desiredState as PRE_MASTER on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_PRE_MASTER_F)         "Unable to configure externalPortConfigurationPortDS.desiredState as PRE_MASTER on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_SLAVE)                "Configure externalPortConfigurationPortDS.desiredState as SLAVE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_SLAVE_F)              "Unable to configure externalPortConfigurationPortDS.desiredState as SLAVE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_SLAVE_ONLY)           "Enable defaultDS.slaveOnly at DUT.\n"
set dut_log_msg(CONFIGURE_SLAVE_ONLY_F)         "Unable to enable defaultDS.slaveOnly at DUT.\n"
set dut_log_msg(CONFIGURE_UNCALIBRATED)         "Configure externalPortConfigurationPortDS.desiredState as UNCALIBRATED on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONFIGURE_UNCALIBRATED_F)       "Unable to configure externalPortConfigurationPortDS.desiredState as UNCALIBRATED on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(CONVERT_DUT_EPOCH)              "Get DUT's time and convert it into epoch Timestamp.\n"
set dut_log_msg(CONVERT_DUT_EPOCH_DTS1)         "Get DUT's time and convert it into epoch Timestamp(DTS1).\n"
set dut_log_msg(CONVERT_DUT_EPOCH_DTS1_F)       "Unable to get DUT's time and convert it into epoch Timestamp.\n"
set dut_log_msg(CONVERT_DUT_EPOCH_DTS2)         "Get DUT's time and convert it into epoch Timestamp(DTS2).\n"
set dut_log_msg(CONVERT_DUT_EPOCH_DTS2_F)       "Unable to get DUT's time and convert it into epoch Timestamp.\n"
set dut_log_msg(CONVERT_DUT_EPOCH_DTS3)         "Get DUT's time and convert it into epoch Timestamp(DTS3).\n"
set dut_log_msg(CONVERT_DUT_EPOCH_DTS3_F)       "Unable to get DUT's time and convert it into epoch Timestamp.\n"
set dut_log_msg(CONVERT_DUT_EPOCH_F)            "Unable to get DUT's time and convert it into epoch Timestamp.\n"
set dut_log_msg(DA1_F)                          "Value of delayAsymmetry is not equal to 0.\n"
set dut_log_msg(DA1_V)                          "Check whether value of delayAsymmetry = 0.\n"
set dut_log_msg(DA5_0_F)                        "Value of delayAsymmentry is not equal to 0.\n"
set dut_log_msg(DA5_0_V)                        "Check whether value of delayAsymmetry = 0.\n"
set dut_log_msg(DEFAULTDS.MASTERONLY_F)         "portDS.masterOnly is set to TRUE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DEFAULTDS.MASTERONLY_FALSE_V)   "Verify that portDS.masterOnly is set to FALSE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DEFAULTDS.MASTERONLY_TRUE_O)    "Check that portDS.masterOnly is set to TRUE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DEFAULTDS.MASTERONLY_NOT_V)     "Verify that DUT does not allow to enable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DEFAULTDS.MASTERONLY_TRUE)      "Configure portDS.masterOnly to TRUE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DEFAULTDS.MASTERONLY_TRUE_F)    "portDS.masterOnly is not set to TRUE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DEFAULTDS.MASTERONLY_V)         "Verify whether portDS.masterOnly is set to FALSE on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DEFAULTDS.SLAVEONLY_F)          "DefaultDS.slaveOnly is set to TRUE.\n"
set dut_log_msg(DEFAULTDS.SLAVEONLY_FALSE)      "Configure defaultDS.slaveOnly to FALSE.\n"
set dut_log_msg(DEFAULTDS.SLAVEONLY_FALSE_F)    "defaultDS.slaveOnly is not set to FALSE.\n"
set dut_log_msg(DEFAULTDS.SLAVEONLY_FALSE_V)    "Verify that defaultDS.slaveOnly is set to FALSE.\n"
set dut_log_msg(DEFAULTDS.SLAVEONLY_NOT_V)      "Verify that DUT does not allow to enable defaultDS.slaveOnly.\n"
set dut_log_msg(DEFAULTDS.SLAVEONLY_TRUE)       "Configure defaultDS.slaveOnly to TRUE.\n"
set dut_log_msg(DEFAULTDS.SLAVEONLY_TRUE_F)     "defaultDS.slaveOnly is not set to TRUE.\n"
set dut_log_msg(DEFAULTDS.SLAVEONLY_TRUE_V)     "Verify that defaultDS.slaveOnly is set to TRUE.\n"
set dut_log_msg(DEFAULTDS.SLAVEONLY_V)          "Verify whether defaultDS.slaveOnly is set to FALSE.\n"
set dut_log_msg(DELAY_REQ_RX)                   "Observe that DUT transmits DELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DELAY_REQ_RX_F)                 "DUT has not transmitted DELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DELAY_RESP_RX_F)                "DUT has not transmitted DELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DELAY_RESP_RX_O)                "Observe that DUT transmits DELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DELAY_RESP_TX)                  "Send periodic DELAY_RESP on port T1 ($::tee_port_num_1).\n"
set dut_log_msg(DELAY_RESP_TX_F)                "Unable to send periodic DELAY_RESP on port T1 ($::tee_port_num_1).\n"
set dut_log_msg(DISABLE_EXTERNAL_PORT_CONFIG)   "Disable defaultDS.externalPortConfigurationEnabled at DUT.\n"
set dut_log_msg(DISABLE_EXTERNAL_PORT_CONFIG_F) "DefaultDS.externalPortConfigurationEnabled cannot be disabled at DUT.\n"
set dut_log_msg(DISABLE_L1SYNC)                 "Disable L1SYNC on port P2 ($::dut_port_num_2).\n"
set dut_log_msg(DISABLE_L1SYNC_P1)              "Disable L1SYNC on DUT's port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DISABLE_L1SYNC_P1_F)            "Disabling L1SYNC on port P1 ($::dut_port_num_1) has failed.\n"
set dut_log_msg(DISABLE_L1SYNC_P2)              "Disable L1SYNC on DUT's port P2 ($::dut_port_num_2).\n"
set dut_log_msg(DISABLE_L1SYNC_P2_F)            "Disabling of L1SYNC on DUT's port P2 ($::dut_port_num_2) has failed.\n"
set dut_log_msg(DISABLE_MO)                     "Disable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DISABLE_MO_F)                   "portDS.masterOnly on port P1 ($::dut_port_num_1) cannot be disabled.\n"
set dut_log_msg(DISABLE_MO_P1)                  "Disable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DISABLE_MO_P1_F)                "Unable to disable portDS.masterOnly on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DISABLE_PORT)                   "Disable DUT's port P1 ($::dut_port_num_1).\n"
set dut_log_msg(DISABLE_PORT_F)                 "Unable to disable DUT's port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ENABLE_CR_P1)                   "Enable CongruentIsRequired on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ENABLE_CR_P1_F)                 "Enabling CongruentIsRequired on port P1 ($::dut_port_num_1) has failed.\n"
set dut_log_msg(ENABLE_EXTERNAL_PORT_CONFIG)    "Enable defaultDS.externalPortConfigurationEnabled.\n"
set dut_log_msg(ENABLE_EXTERNAL_PORT_CONFIG_F)  "Enabling of defaultDS.externalPortConfigurationEnabled has failed.\n"
set dut_log_msg(ENABLE_L1SYN_OPT_PARAMS)        "Enable optParamsEnabled on DUT.\n"
set dut_log_msg(ENABLE_L1SYN_OPT_PARAMS_F)      "Enabling of optParamsEnabled on DUT has failed.\n"
set dut_log_msg(ENABLE_L1SYNC_F)                "Enabling of L1SYNC on DUT's port P1 ($::dut_port_num_1) has failed.\n"
set dut_log_msg(ENABLE_L1SYNC_P1)               "Enable L1SYNC on DUT's port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ENABLE_L1SYNC_TCT)              "Enable timestampsCorrectedTx on DUT.\n"
set dut_log_msg(ENABLE_L1SYNC_TCT_F)            "Enabling of timestampsCorrectedTx on DUT has failed.\n"
set dut_log_msg(ENABLE_PORT)                    "Enable DUT's port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ENABLE_PORT_F)                  "Unable to enable DUT's port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ENABLE_RCR_P1)                  "Enable RxCoherentIsRequired on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ENABLE_RCR_P1_F)                "Enabling RxCoherentIsRequired on port P1 ($::dut_port_num_1) has failed.\n"
set dut_log_msg(ENABLE_TCR_P1)                  "Enable TxCoherentIsRequired on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ENABLE_TCR_P1_F)                "Enabling TxCoherentIsRequired port P1 ($::dut_port_num_1) has failed.\n"
set dut_log_msg(ENABLE_TCR_RCR_CR)              "Enable txCoherentIsRequired,rxCoherentIsRequired and congruentIsRequired on DUT's port P1 ($::dut_port_num_1).\n"
set dut_log_msg(ENABLE_TCR_RCR_CR_F)            "Unable to enable txCoherentIsRequired,rxCoherentIsRequired and congruentIsRequired on DUT's port P1 ($::dut_port_num_1).\n"
set dut_log_msg(EXTPORT_CONFIGURE_F)            "DefaultDS.externalPortConfigurationEnabled is set to TRUE.\n"
set dut_log_msg(EXTPORT_CONFIGURE_V)            "Verify whether defaultDS.externalPortConfigurationEnabled is set to FALSE.\n"
set dut_log_msg(FOLLOW_UP_RX_F)                 "DUT has not transmitted FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(FOLLOW_UP_RX_O)                 "Observe that DUT transmits FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD1)          "Get currentDS.meanDelay MD1 of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD1_F)        "Unable to get currentDS.meanDelay of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD2)          "Get currentDS.meanDelay MD2 of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD2_F)        "Unable to get currentDS.meanDelay of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD3)          "Get currentDS.meanDelay MD3 of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD3_F)        "Unable to get currentDS.meanDelay of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD4)          "Get currentDS.meanDelay MD4 of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD4_F)        "Unable to get currentDS.meanDelay of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD5)          "Get currentDS.meanDelay MD5 of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD5_F)        "Unable to get currentDS.meanDelay of DUT.\n"
set dut_log_msg(GET_CDS.MEANDELAY_MD_TEE)       "Calculate currentDS.meanDelay at TEE.\n"
set dut_log_msg(GET_CDS.OFM1)                   "Get currentDS.offsetFromMaster (OFM1) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_CDS.OFM1_F)                 "Unable to get currentDS.offsetFromMaster (OFM1) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA1)        "Get delayAsymmetry (DA1) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA1_F)      "Unable to get delayAsymmetry (DA1) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA2)        "Get delayAsymmetry (DA2) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA2_F)      "Unable to get delayAsymmetry (DA2) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA3)        "Get delayAsymmetry (DA3) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA3_F)      "Unable to get delayAsymmetry (DA3) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA4)        "Get delayAsymmetry (DA4) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA4_F)      "Unable to get delayAsymmetry (DA4) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA5)        "Get delayAsymmetry (DA5) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_DELAY_ASYMMETRY_DA5_F)      "Unable to get delayAsymmetry (DA5) value for port P1 ($::dut_port_num_1).\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD1)       "Get portDS.meanLinkDelay (MLD1) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD1_F)     "Unable to get portDS.meanLinkDelay (MLD1) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD2)       "Get portDS.meanLinkDelay (MLD2) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD2_F)     "Unable to get portDS.meanLinkDelay (MLD2) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD3)       "Get portDS.meanLinkDelay (MLD3) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD3_F)     "Unable to get portDS.meanLinkDelay (MLD3) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD4)       "Get portDS.meanLinkDelay (MLD4) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD4_F)     "Unable to get portDS.meanLinkDelay (MLD4) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD5)       "Get portDS.meanLinkDelay (MLD5) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(GET_MEAN_LINK_DELAY_MLD5_F)     "Unable to get portDS.meanLinkDelay (MLD5) value for port P1 ($::dut_port_num_1) in DUT.\n"
set dut_log_msg(INIT_SETUP1)                    "Initialize the DUT for Test setup 1.\n"
set dut_log_msg(INIT_SETUP1_F)                  "Initialization of DUT for Test setup 1 has failed.\n"
set dut_log_msg(INIT_SETUP2)                    "Initialize the DUT for Test setup 2.\n"
set dut_log_msg(INIT_SETUP2_F)                  "Initialization of DUT for Test setup 2 has failed.\n"
set dut_log_msg(INIT_SETUP3)                    "Initialize the DUT for Test setup 3.\n"
set dut_log_msg(INIT_SETUP3_F)                  "Initialization of DUT for Test setup 3 has failed.\n"
set dut_log_msg(INIT_SETUP4)                    "Initialize the DUT for Test setup 4.\n"
set dut_log_msg(INIT_SETUP4_F)                  "Initialization of DUT for Test setup 4 has failed.\n"
set dut_log_msg(INIT_SETUP5)                    "Initialize the DUT for Test setup 5.\n"
set dut_log_msg(INIT_SETUP5_F)                  "Initialization of DUT for Test setup 5 has failed.\n"
set dut_log_msg(INIT_SETUP6)                    "Initialize the DUT for Test setup 6.\n"
set dut_log_msg(INIT_SETUP6_F)                  "Initialization of DUT for Test setup 6 has failed.\n"
set dut_log_msg(INIT_SETUP7)                    "Initialize the DUT for Test setup 7.\n"
set dut_log_msg(INIT_SETUP7_F)                  "Initialization of DUT for Test setup 7 has failed.\n"
set dut_log_msg(INIT_SETUP8)                    "Initialize the DUT for Test setup 8.\n"
set dut_log_msg(INIT_SETUP8_F)                  "Initialization of DUT for Test setup 8 has failed.\n"
set dut_log_msg(INIT_SETUP9)                    "Initialize the DUT for Test setup 9.\n"
set dut_log_msg(INIT_SETUP9_F)                  "Initialization of DUT for Test setup 9 has failed.\n"
set dut_log_msg(L1SYNC_RX_P1_F)                 "DUT has not transmitted PTP signaling message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(L1SYNC_RX_P1_O)                 "Observe that DUT transmits PTP signaling message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(L1SYNC_RX_P1_V)                 "Verify that DUT transmits PTP signaling message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(L1SYNC_TX_T1)                   "Send PTP SIGNALING message with L1 Sync TLV on port T1 ($::tee_port_num_1).\n"
set dut_log_msg(MD_LESSER_MD1_O)                "Observe that MD2 is lesser than MD1.\n"
set dut_log_msg(MD2_LESSER_MD1_F)               "MD2 is not lesser than MD1.\n"
set dut_log_msg(MD2_LESSER_MD1_O)               "Observe that MD2 is lesser than MD1.\n"
set dut_log_msg(MD3_GREATER_MD1_F)              "MD3 is not greater than MD1.\n"
set dut_log_msg(MD3_GREATER_MD1_V)              "Verify that MD3 is greater than MD1.\n"
set dut_log_msg(MD3_GREATER_MD2_V)              "Verify that MD3 is greater than MD1.\n"
set dut_log_msg(NO_ENABLE_EXTERNAL_PORT_CONFIG) "Verify that the DUT does not allow to enable defaultDS.externalPortConfigurationEnabled.\n"
set dut_log_msg(TIME_DIFF_DTS1_SEET1_GREATER_F) "Time difference of DTS1 and SEET1 is not greater than 0.\n"
set dut_log_msg(TIME_DIFF_DTS1_SEET1_GREATER_O) "Observe that time difference of DTS1 and SEET1 is greater than 0.\n"
set dut_log_msg(TIME_DIFF_DTS2_SEET2_GREATER_1_F) "Time difference of DTS2 and SEET2 is not greater than 1.\n"
set dut_log_msg(TIME_DIFF_DTS2_SEET2_GREATER_1_O) "Observe that time difference of DTS2 and SEET2 is greater than 1.\n"
set dut_log_msg(TIME_DIFF_SEET3_DTS3_GREATER_1_V) "Verify that time difference of DTS3 and SEET3 is greater than 1.\n"
set dut_log_msg(TIME_DIFF_DTS1_SEET1_LESSER_1_F)  "Time difference of DTS1 and SEET1 is not lesser than 1.\n"
set dut_log_msg(TIME_DIFF_DTS1_SEET1_LESSER_1_O)  "Observe that time difference of DTS1 and SEET1 is lesser than 1.\n"
set dut_log_msg(TIME_DIFF_DTS2_SEET2_LESSER_F)  "Time difference of DTS2 and SEET2 is not lesser than 0.\n"
set dut_log_msg(TIME_DIFF_DTS2_SEET2_LESSER_O)  "Observe that time difference of DTS2 and SEET2 is lesser than 0.\n"
set dut_log_msg(TIME_DIFF_F)                    "Unable to find the time difference of DTS and SEET.\n"
set dut_log_msg(TIME_DIFF_SEET3_DTS3_LESSER_V)  "Verify that time difference of SEET3 and DTS3 is less than 0.\n"
set dut_log_msg(TIME_DIFF_TD1_GREATER_F)        "Time difference TD1 is not greater than 0.\n"
set dut_log_msg(TIME_DIFF_TD1_GREATER_O)        "Observe that time difference TD1 is greater than 0.\n"
set dut_log_msg(TIME_DIFF_TD2_LESSER_F)         "Time difference TD2 is not lesser than 0.\n"
set dut_log_msg(TIME_DIFF_TD2_LESSER_O)         "Observe that time difference TD2 is lesser than 0.\n"
set dut_log_msg(TIME_DIFF_TD3_GREATER_F)        "Time difference TD3 is not lesser than 0.\n"
set dut_log_msg(TIME_DIFF_TD3_LESSER_V)         "Verify that time difference TD3 is lesser than 0.\n"
set dut_log_msg(TIME_DIFF_V)                    "Verify that time difference of SEET and DTS.\n"
set dut_log_msg(TXPORTDS.CONSTANTASYMMETRY_F)   "DUT does not allow to configure asymmetryCorrectionPortDS.constantAsymmetry on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.CONSTANTASYMMETRY_N_F) "DUT allows to configure asymmetryCorrectionPortDS.constantAsymmetry on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.CONSTANTASYMMETRY_N_O) "Observe that DUT does not allow to configure asymmetryCorrectionPortDS.constantAsymmetry on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.CONSTANTASYMMETRY_O)   "Observe that DUT allows to configure asymmetryCorrectionPortDS.constantAsymmetry on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.CONSTANTASYMMETRY_V)   "Verify that DUT allows to configure asymmetryCorrectionPortDS.constantAsymmetry on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.EGRESSLATENCY_F)       "DUT does not allow to configure timestampCorrectionPortDS.egressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.EGRESSLATENCY_N_F)     "DUT allows to configure timestampCorrectionPortDS.egressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.EGRESSLATENCY_N_O)     "Observe that DUT does not allow to configure timestampCorrectionPortDS.egressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.EGRESSLATENCY_O)       "Observe that DUT allows to configure timestampCorrectionPortDS.egressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.EGRESSLATENCY_V)       "Check whether the DUT allows to configure timestampCorrectionPortDS.egressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.INGRESSLATENCY_F)      "DUT does not allow to configure timestampCorrectionPortDS.ingressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.INGRESSLATENCY_N_F)    "DUT allows to configure timestampCorrectionPortDS.ingressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.INGRESSLATENCY_N_O)    "Observe that DUT does not allow to configure timestampCorrectionPortDS.ingressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.INGRESSLATENCY_O)      "Observe that DUT allows to configure timestampCorrectionPortDS.ingressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.INGRESSLATENCY_V)      "Check whether the DUT allows to configure timestampCorrectionPortDS.ingressLatency on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.SCALEDDELAYCOEFFICIENT_F)      "DUT does not allow to configure timestampCorrectionPortDS.scaledDelayCoefficient\n on port P1 ($::dut_port_num_1)."
set dut_log_msg(TXPORTDS.SCALEDDELAYCOEFFICIENT_N_F)    "DUT allows to configure timestampCorrectionPortDS.scaledDelayCoefficient\n"
set dut_log_msg(TXPORTDS.SCALEDDELAYCOEFFICIENT_N_O)    "Observe that DUT does not allow to configure timestampCorrectionPortDS.scaledDelayCoefficient on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.SCALEDDELAYCOEFFICIENT_O)      "Observe that DUT allows to configure timestampCorrectionPortDS.scaledDelayCoefficient on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(TXPORTDS.SCALEDDELAYCOEFFICIENT_V)      "Verify that DUT allows to configure timestampCorrectionPortDS.scaledDelayCoefficient on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(VERIFY_MD1)                     "Verify that  MD2 < MD1 & MD3 > MD1.\n"
set dut_log_msg(WAIT)                           "Wait for DUT to update domain number (60s).\n"
set dut_log_msg(WAIT_10)                        "Wait for expiry of 10s.\n"
set dut_log_msg(WAIT_2)                         "Wait for expiry of 2s.\n"
set dut_log_msg(WAIT_3)                         "Wait for expiry of 3s.\n"
set dut_log_msg(WAIT_5)                         "Wait for expiry of 5s.\n"
set dut_log_msg(WAIT_ANNOUNCE_RECEIPT_TIMEOUT)  "Wait for the expiry of AnnounceReceiptTimeout (${::ptp_ha_bmca}s).\n"
set dut_log_msg(WAIT_BMCA)                      "Wait for completing BMCA (${::ptp_ha_bmca}s).\n"
set dut_log_msg(WAIT_L1SYNCRECEIPTTIMEOUT)      "Wait for the expiry of L1SyncReceiptTimeout (${::ptp_ha_l1sync_timeout_d}s).\n"
set dut_log_msg(WAIT_TWICE_L1SYNCRECEIPTTIMEOUT) "Wait for the expiry of twice the L1SyncReceiptTimeout (${::ptp_ha_l1sync_timeout_twice}s).\n"
set dut_log_msg(WAIT_QUALIFICATION_TIMEOUT)     "Wait for the expiry of qualificationTimeoutInterval (${::ptp_ha_announce_timeout}s).\n"


### TEE LOG MESSAGES ###
set tee_log_msg(ANN_RX_P2_F)                    "DUT has not transmitted ANNOUNCE message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(ANN_RX_P2_V)                    "Verify that DUT transmits ANNOUNCE message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(ANN_TX_T1)                      "Send ANNOUNCE message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(ANN_TX_T1_F)                    "Unable to send ANNOUNCE message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(ANNOUNCE_NRX_P1_F)              "DUT has transmitted ANNOUNCE message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(ANNOUNCE_NRX_P1_O)              "Observe that DUT does not transmit ANNOUNCE message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(ANNOUNCE_NRX_P1_V)              "Verify that DUT does not transmit ANNOUNCE message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(ANNOUNCE_RX_P1_F)               "DUT has not transmitted ANNOUNCE message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(ANNOUNCE_RX_P1_O)               "Observe that DUT transmits ANNOUNCE message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(ANNOUNCE_RX_P1_V)               "Verify that DUT transmits ANNOUNCE message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(ANNOUNCE_RX_P2_F)               "DUT has not transmitted ANNOUNCE message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(ANNOUNCE_RX_P2_O)               "Observe that DUT transmits ANNOUNCE message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(ANNOUNCE_RX_P2_V)               "Verify that DUT transmits ANNOUNCE message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(ARP_F)                          "Unicast pre-requisite is failed due to failure of ARP resolution.\n"
set tee_log_msg(CALC_MD1)                       "Calculate Mean Delay (MD1) at TEE.\n"
set tee_log_msg(CALC_MD2)                       "Calculate Mean Delay (MD2) at TEE.\n"
set tee_log_msg(CALC_MD3)                       "Calculate Mean Delay (MD3) at TEE.\n"
set tee_log_msg(DELAY_REQ_RX_F)                 "DUT has not transmitted DELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(DELAY_REQ_RX_O)                 "Observe that the DUT transmits DELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(DELAY_REQ_RX_P1_F)              "DUT has not transmited DELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(DELAY_REQ_RX_P1_O)              "Observe that DUT transmits DELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(DELAY_REQ_TX)                   "Send DELAY_REQ message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(DELAY_REQ_TX_F)                 "Unable to send DELAY_REQ message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(DELAY_RESP_RX_F)                "DUT has not transmitted DELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(DELAY_RESP_RX_O)                "Observe that DUT transmits DELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(DELAY_RESP_RX_P1_F)             "DUT has not transmitted DELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(DELAY_RESP_RX_P1_O)             "Observe that the DUT transmits DELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(DELAY_RESP_TX_T1)               "Send DELAY_RESP message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(DELAY_RESP_TX_T1_F)             "Unable to send DELAY_RESP message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(DISABLE_T1)                     "Disable port T1 ($::tee_port_num_1).\n"
set tee_log_msg(DISABLE_T1_F)                   "Unable to disable port T1 ($::tee_port_num_1).\n"
set tee_log_msg(ENABLE_RESPONDER_TO_DELAY_REQ)  "Enable auto responder to respond every Delay_Req messages received on port T1 ($::tee_port_num_1)."
set tee_log_msg(ENABLE_RESPONDER_TO_PDELAY_REQ) "Enable auto responder to respond every Pdelay_Req messages received on port T1 ($::tee_port_num_1)."
set tee_log_msg(FILTER_F)                       "Filter creation is failed for PTP messages.\n"
set tee_log_msg(FOLLOW_UP_RX_F)                 "DUT has not transmitted FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(FOLLOW_UP_RX_O)                 "Observe that DUT transmits FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(FOLLOW_UP_RX_P1_F)              "DUT has not transmitted FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(FOLLOW_UP_RX_P1_O)              "Observe that DUT transmits FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(FOLLOWUP_TX_T1)                 "Send periodic FOLLOW_UP message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(FOLLOWUP_TX_T1_F)               "Unable to send periodic FOLLOW_UP message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(IEEE)                           "This test case is applicable only for transport over IEEE 802.3/Ethernet.\n"
set tee_log_msg(INIT)                           "Initialization of TEE.\n"
set tee_log_msg(INIT_SETUP_1)                   "Initialization of TEE setup 1.\n"
set tee_log_msg(INIT_SETUP_1_F)                 "Unable to initialize TEE setup 1.\n"
set tee_log_msg(INIT_SETUP_6)                   "Initialization of TEE setup 6.\n"
set tee_log_msg(INIT_SETUP_6_F)                 "Unable to initialize TEE setup 6.\n"
set tee_log_msg(L1SYNC_NRX_P1_F)                "DUT transmits L1SYNC signaling message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(L1SYNC_NRX_P1_O)                "Observe that DUT does not transmit L1SYNC signaling message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(L1SYNC_NRX_P1_V)                "Verify that DUT does not transmit L1SYNC signaling message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(L1SYNC_NRX_P2_F)                "DUT has transmitted L1SYNC message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(L1SYNC_NRX_P2_O)                "Observe that DUT does not transmit L1SYNC signaling message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(L1SYNC_NRX_P2_V)                "Verify that DUT does not transmit L1SYNC signaling message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(L1SYNC_RX_F)                    "DUT has not transmitted L1SYNC message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(L1SYNC_RX_O)                    "Observe that DUT transmits L1SYNC message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(L1SYNC_RX_P1_F)                 "DUT has not transmitted L1SYNC message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(L1SYNC_RX_P1_O)                 "Observe that DUT transmits L1SYNC message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(L1SYNC_RX_P1_V)                 "Verify that DUT transmits L1SYNC message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(L1SYNC_RX_P2_F)                 "DUT has not transmitted L1SYNC message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(L1SYNC_RX_P2_O)                 "Observe that DUT transmits L1SYNC message on port P2 ($::dut_port_num_2).\n"
set tee_log_msg(L1SYNC_RX_V)                    "Verify that DUT transmits L1SYNC message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(L1SYNC_TX_T1)                   "Send L1SYNC signaling message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(L1SYNC_TX_T1_F)                 "Unable to send L1SYNC signaling message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(P2P_DLY_MECHANISM)              "This test is applicable only if peer-to-peer delay mechanism is supported. If it is supported, choose the support in ATTEST GUI (Go to Configuration Manager and select desired configuration, go to Protocol Options > PTP-HA > Global)."
set tee_log_msg(PDELAY_REQ_RX_F)                "DUT has not transmitted PDELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(PDELAY_REQ_RX_O)                "Observe that the DUT transmits PDELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(PDELAY_REQ_RX_P1_F)             "DUT has not transmitted PDELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(PDELAY_REQ_RX_P1_O)             "Observe that DUT transmits PDELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(PDELAY_REQ_TX)                  "Send PDELAY_REQ message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(PDELAY_REQ_TX_F)                "Unable to send PDELAY_REQ message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(PDELAY_RESP_FOLLOW_UP_RX_P1_F)  "DUT has not transmitted PDELAY_RESP_FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(PDELAY_RESP_FOLLOW_UP_RX_P1_O)  "Observe that DUT transmits PDELAY_RESP_FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(PDELAY_RESP_RX_P1_F)            "DUT has not transmitted PDELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(PDELAY_RESP_RX_P1_O)            "Observe that DUT transmits PDELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(PDELAY_RESP_TX)                 "Send periodic PDELAY_RESP on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(PDELAY_RESP_TX_F)               "Unable to send periodic PDELAY_RESP on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(SKIP_STEP)                      "Verification of this step is skipped as DUT did not allow configuration in previous step.\n"

set dut_log_msg(PDELAY_REQ_RX)                  "Observe that DUT transmits PDELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(PDELAY_REQ_RX_F)                "DUT has not transmitted PDELAY_REQ message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(PDELAY_RESP_FOLLOW_UP_RX_P1_F)  "DUT has not transmitted PDELAY_RESP_FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(PDELAY_RESP_FOLLOW_UP_RX_P1_O)  "Observe that DUT transmits PDELAY_RESP_FOLLOW_UP message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(PDELAY_RESP_RX_P1_F)            "DUT has not transmitted PDELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(PDELAY_RESP_RX_P1_O)            "Observe that DUT transmits PDELAY_RESP message on port P1 ($::dut_port_num_1).\n"
set dut_log_msg(PDELAY_RESP_TX)                 "Send periodic PDELAY_RESP on port T1 ($::tee_port_num_1).\n"
set dut_log_msg(PDELAY_RESP_TX_F)               "Unable to send periodic PDELAY_RESP on port T1 ($::tee_port_num_1).\n"
set dut_log_msg(SYNC_TX_T1)                     "Send periodic SYNC message on port T1 ($::tee_port_num_1).\n"
set dut_log_msg(SYNC_TX_T1_F)                   "Unable to send periodic SYNC message on port T1 ($::tee_port_num_1).\n"

set tee_log_msg(STOP_ANNOUNCE_TX_T1)            "Stop ANNOUNCE messages on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(STOP_ANNOUNCE_TX_T1_F)          "ANNOUNCE messages cannot be stopped on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(STOP_FOLLOWUP_TX_T1)            "Stop FOLLOWUP messages on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(STOP_FOLLOWUP_TX_T1_F)          "FOLLOWUP messages cannot be stopped on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(STOP_L1SYNC_TX_T1)              "Stop sending L1SYNC signaling message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(STOP_L1SYNC_TX_T1_F)            "Unable to stop sending L1SYNC signaling message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(STOP_SYNC_TX_T1)                "Stop SYNC messages on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(STOP_SYNC_TX_T1_F)              "SYNC messages cannot be stopped on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(SYNC_RX_P1_F)                   "DUT has not transmitted SYNC message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(SYNC_RX_P1_O)                   "Observe that DUT transmits SYNC message on port P1 ($::dut_port_num_1).\n"
set tee_log_msg(SYNC_TX_T1)                     "Send periodic SYNC message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(SYNC_TX_T1_F)                   "Unable to send periodic SYNC message on port T1 ($::tee_port_num_1).\n"
set tee_log_msg(UDP)                            "This test case is applicable only for transport over UDP/IPV4.\n"
set tee_log_msg(WAIT_L1SYNC_RX_INTR)            "Wait for ${::ptp_ha_l1sync_timeout_d}s for the expiry of l1syncReceiptTimeoutInterval.\n"
set tee_log_msg(WAIT_L1SYNC_UP_STATE)           "Wait for the transition L1SYNC state of port P1 ($::dut_port_num_1) to L1_SYNC_UP.\n"

## ERROR MESSAGE

set err_desc  "is not matching"

array set tee_rx_errlog "
    -1  \"\"
     0  \"\"
     1  \"(Reason: Destination MAC $err_desc)\"
     2  \"(Reason: Source MAC $err_desc)\"
     3  \"(Reason: EthType $err_desc)\"
     4  \"(Reason: VLAN ID $err_desc)\"
     5  \"(Reason: VLAN Priority $err_desc)\"
     6  \"(Reason: VLAN DEI $err_desc)\"
     7  \"(Reason: IP Checksum $err_desc)\"
     8  \"(Reason: IP Protocol $err_desc)\"
     9  \"(Reason: Source IP $err_desc)\"
    10  \"(Reason: Destination IP $err_desc)\"
    11  \"(Reason: Source Port $err_desc)\"
    12  \"(Reason: Destination Port $err_desc)\"
    13  \"(Reason: UDP Length $err_desc)\"
    14  \"(Reason: UDP_Checksum $err_desc)\"
    15  \"(Reason: majorSdoId $err_desc)\"
    16   \"\"
    17  \"(Reason: minorVersionPTP $err_desc)\"
    18  \"(Reason: versionPTP $err_desc)\"
    19  \"(Reason: messageLength $err_desc)\"
    20  \"(Reason: domainNumber $err_desc)\"
    21  \"(Reason: minorSdoId $err_desc)\"
    22  \"(Reason: alternateMasterFlag $err_desc)\"
    23  \"(Reason: twoStepFlag $err_desc)\"
    24  \"(Reason: unicastFlag $err_desc)\"
    25  \"(Reason: PTP Profile Specific 1 $err_desc)\"
    26  \"(Reason: PTP Profile Specific 2 $err_desc)\"
    27  \"(Reason: secure $err_desc)\"
    28  \"(Reason: leap61 $err_desc)\"
    29  \"(Reason: leap59 $err_desc)\"
    30  \"(Reason: currentUtcOffsetValid $err_desc)\"
    31  \"(Reason: ptpTimescale $err_desc)\"
    32  \"(Reason: timeTraceable $err_desc)\"
    33  \"(Reason: frequencyTraceable $err_desc)\"
    34  \"(Reason: synchronizationUncertain $err_desc)\"
    35  \"(Reason: correctionField $err_desc)\"
    36  \"(Reason: messageTypeSpecific $err_desc)\"
    37  \"(Reason: sourcePortNumber $err_desc)\"
    38  \"(Reason: sourceClockIdentity $err_desc)\"
    39  \"(Reason: sequenceId $err_desc)\"
    40  \"(Reason: controlField $err_desc)\"
    41  \"(Reason: logMessageInterval $err_desc)\"
    42  \"(Reason: originTimestamp sec $err_desc)\"
    43  \"(Reason: originTimestamp ns $err_desc)\"
    44  \"(Reason: currentUtcOffset $err_desc)\"
    45  \"(Reason: grandmasterPriority1 $err_desc)\"
    46  \"(Reason: grandmasterPriority2 $err_desc)\"
    47  \"(Reason: grandmasterIdentity $err_desc)\"
    48  \"(Reason: stepsRemoved $err_desc)\"
    49  \"(Reason: timeSource $err_desc)\"
    50  \"(Reason: clockClass $err_desc)\"
    51  \"(Reason: clockAccuracy $err_desc)\"
    52  \"(Reason: offsetScaledLogVariance $err_desc)\"
    53  \"(Reason: preciseOriginTimestamp sec $err_desc)\"
    54  \"(Reason: preciseOriginTimestamp ns $err_desc)\"
    55  \"(Reason: receiveTimestamp sec $err_desc)\"
    56  \"(Reason: receiveTimestamp ns $err_desc)\"
    57  \"(Reason: requestingPortNumber $err_desc)\"
    58  \"(Reason: requestingClockIdentity $err_desc)\"
    59  \"(Reason: requestReceiptTimestamp sec $err_desc)\"
    60  \"(Reason: requestReceiptTimestamp ns $err_desc)\"
    61  \"(Reason: responseOriginTimestamp sec $err_desc)\"
    62  \"(Reason: responseOriginTimestamp ns $err_desc)\"
    63  \"(Reason: targetPortNumber $err_desc)\"
    64  \"(Reason: targetClockIdentity $err_desc)\"
    65  \"(Reason: startingBoundaryHops $err_desc)\"
    66  \"(Reason: boundaryHops $err_desc)\"
    67  \"(Reason: actionField $err_desc)\"
    68  \"(Reason: TLV $err_desc)\"
    69  \"(Reason: tlvType $err_desc)\"
    70  \"(Reason: tlvLength $err_desc)\"
    71  \"(Reason: optParamsEnabled $err_desc)\"
    72  \"(Reason: congruentIsRequired $err_desc)\"
    73  \"(Reason: rxCoherentIsRequired $err_desc)\"
    74  \"(Reason: txCoherentIsRequired $err_desc)\"
    75  \"(Reason: isCongruent $err_desc)\"
    76  \"(Reason: isRxCoherent $err_desc)\"
    77  \"(Reason: isTxCoherent $err_desc)\"
    78  \"(Reason: frequencyOffsetTxValid $err_desc)\"
    79  \"(Reason: phaseOffsetTxValid $err_desc)\"
    80  \"(Reason: timestampsCorrectedTx $err_desc)\"
    81  \"(Reason: phaseOffsetTx $err_desc)\"
    82  \"(Reason: phaseOffsetTxTimestamp sec $err_desc)\"
    83  \"(Reason: phaseOffsetTxTimestamp ns $err_desc)\"
    84  \"(Reason: freqOffsetTx $err_desc)\"
    85  \"(Reason: freqOffsetTxTimestamp sec $err_desc)\"
    86  \"(Reason: freqOffsetTxTimestamp ns $err_desc)\"
    87  \"(Reason: managementId $err_desc)\"
    88  \"(Reason: externalPortConfigurationEnabled $err_desc)\"
    89  \"(Reason: masterOnly $err_desc)\"
    90  \"(Reason: sourcePortIdentity $err_desc)\"
    91  \"(Reason: targetPortIdentity $err_desc)\"
"
